@@ -1,12 +1,11 @@
 /* helptext.c  - English help texts
- * Copyright (C) 1998, 1999, 2000, 2001, 2002,
- *               2004 Free Software Foundation, Inc.
+ * Copyright (C) 1998, 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
  *
  * This file is part of GnuPG.
  *
  * GnuPG is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
+ * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
  * GnuPG is distributed in the hope that it will be useful,
@@ -15,13 +14,16 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
 #include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+
+#include "gpg.h"
 #include "util.h"
 #include "ttyio.h"
 #include "main.h"
@@ -56,6 +58,10 @@ static struct helptexts { const char *key; const char *help; } helptexts[] = {
  "ultimately trusted\n"
 )},
 
+{ "revoked_key.override", N_(
+"If you want to use this revoked key anyway, answer \"yes\"."
+)},
+
 { "untrusted_key.override", N_(
 "If you want to use this untrusted key anyway, answer \"yes\"."
 )},
@@ -67,17 +73,29 @@ static struct helptexts { const char *key; const char *help; } helptexts[] = {
 { "keygen.algo", N_(
 "Select the algorithm to use.\n"
 "\n"
-"DSA (aka DSS) is the Digital Signature Algorithm and can only be used\n"
-"for signatures.\n"
+"DSA (aka DSS) is the digital signature algorithm which can only be used\n"
+"for signatures.  This is the suggested algorithm because verification of\n"
+"DSA signatures are much faster than those of ElGamal.\n"
 "\n"
-"Elgamal is an encrypt-only algorithm.\n"
+"ElGamal is an algorithm which can be used for signatures and encryption.\n"
+"OpenPGP distinguishs between two flavors of this algorithms: an encrypt only\n"
+"and a sign+encrypt; actually it is the same, but some parameters must be\n"
+"selected in a special way to create a safe key for signatures: this program\n"
+"does this but other OpenPGP implementations are not required to understand\n"
+"the signature+encryption flavor.\n"
 "\n"
-"RSA may be used for signatures or encryption.\n"
-"\n"
-"The first (primary) key must always be a key which is capable of signing."
+"The first (primary) key must always be a key which is capable of signing;\n"
+"this is the reason why the encryption only ElGamal key is not available in\n"
+"this menu."
 )},
 
 
+{ "keygen.algo.elg_se", N_(
+"Although these keys are defined in RFC2440 they are not suggested\n"
+"because they are not supported by all programs and signatures created\n"
+"with them are quite large and very slow to verify."
+)},
+
 { "keygen.algo.rsa_se", N_(
 "In general it is not a good idea to use the same key for signing and\n"
 "encryption.  This algorithm should only be used in certain domains.\n"
@@ -181,7 +199,7 @@ static struct helptexts { const char *key; const char *help; } helptexts[] = {
 )},
 
 { "keyedit.sign_all.okay", N_(
- "Answer \"yes\" if you want to sign ALL the user IDs"
+ "Answer \"yes\" is you want to sign ALL the user IDs"
 )},
 
 { "keyedit.remove.uid.okay", N_(
